@@ -54,6 +54,7 @@ our @EXPORT_OK = qw/
 	init_io
 	libpng_supports
 	permit_mng_features
+	read_end
 	read_from_scalar
 	read_image
 	read_info
@@ -128,6 +129,9 @@ our @EXPORT_OK = qw/
 	sig_cmp
 	split_alpha
 	text_compression_name
+	write_end
+	write_image
+	write_info
 	write_png
 	write_to_scalar
 	color_type_name
@@ -145,7 +149,7 @@ our %EXPORT_TAGS = (
 );
 
 require XSLoader;
-our $VERSION = '0.52_02';
+our $VERSION = '0.52_03';
 
 XSLoader::load('Image::PNG::Libpng', $VERSION);
 
